#
# spec file for package DSView
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           DSView
Version:        1.3.2
Release:        1.2
Summary:        GUI for DreamSourceLab USB-based instruments
License:        GPL-3.0-or-later
Group:          Productivity/Scientific/Electronics
URL:            https://www.dreamsourcelab.com
Source0:        https://github.com/DreamSourceLab/DSView/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Patch0:         0000-added-missing-includes.patch

BuildRequires:  boost-devel
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  fftw3-devel
BuildRequires:  gcc-c++
BuildRequires:  glib2-devel
BuildRequires:  libqt5-qtbase-devel
BuildRequires:  libusb-1_0-devel
BuildRequires:  python3-devel
BuildRequires:  zlib-devel

Obsoletes:      libsigrok4DSL1
Obsoletes:      libsigrokdecode4DSL4

%description
GUI for DreamSourceLab USB-based instruments

%prep
%autosetup -p1

%build
%cmake
%cmake_build

%check
%ctest

%install
%cmake_install
%fdupes %{buildroot}%{_datadir}

%files
%license COPYING
%{_bindir}/%{name}
%{_datadir}/%{name}/
%{_datadir}/applications/dsview.desktop
%{_datadir}/icons/hicolor
%{_datadir}/icons/hicolor/scalable
%{_datadir}/icons/hicolor/scalable/apps
%{_datadir}/icons/hicolor/scalable/apps/dsview.svg
%{_datadir}/pixmaps/dsview.svg
%{_datadir}/libsigrokdecode4DSL/
%{_udevrulesdir}/*

%changelog
* Thu Oct 17 2024 Mikhail Paulyshka <me@mixaill.net>
- Added 0000-added-missing-includes.patch to fix build
- Remove various unnecessary BuildRequires
- Update to v1.3.2
  common
  * Fix crashes when dragging windows between screens
  * Add drag-and-drop and window arrangement support for native Windows windows
  * Improve adaptive window and font display at different DPI settings
  * Fix the issue of missing firmware on macOS
  * Modify the color allocation of the cursor to improve clarity.
  * Fix log file creation issue on Windows
  * Fix display area coverage and font rendering problems
  for logic analyzer
  * Add region waveform save and export feature
  * Fix crashes from cursor placement beyond waveform area during decoding
  * Fix crashes with specific sampling parameters in loop mode
  * Fix crashes from multi-byte search in decoding results
  * Improve distance measurement edge selection
  * Add reminder for channel settings when adding a decoder
  * Implement auto-scroll to latest waveform in loop mode
  * Fix protocol decoding issues (CAN/QSPI/DMX512/LIN/...)
  for oscilloscope
  * Improve pulse count measurement accuracy
  * Fix file export issue with single channel enabled
  * Resolve crashes from FFT parameter modification during data acquisition
  * Fix waveform and vertical resolution calculation issues in math operations
  * Fix waveform anomalies from channel offset exceeding boundaries
  * Improve accuracy of mouse measurements
- Update to v1.3.1
  common
  * Fix the erroneous bin files released for Linux/macOS systems
  for logic analyzer
  * Add support for new hardware (USB2.0 interface/1G sampling rate)
  * Fix the external clock issue with the U3Pro series
  * Fix the issue with trigger position display in repeat mode
  * Fix the problem with the mouse measurements in repeat mode
  * Improve the accuracy of threshold voltage
  * Fix the issue with the Timing decoder
  * Expand the number of bytes decoded per frame for the DMX512 decoder
  for oscilloscope
  * Fix the incorrect measurements on first trigger for U3P100
  * Fix the error in measurements when the window size changes
  * Fix the issue with saving measurements into DSL files
  * Fix the loading error of duty cycle in DSL files
  for data acquisiton
  * Fix the issue with incorrect values when export CSV file
  * Fix the problem with waveform display when the window size changes
  * Fix the issues with waveform when different channel are enabled
- Update to v1.3.0
  common
  * Improve device management, decouple it from wave acquisition and display
  * Add support for dynamically switching font sizes
  * Modify the multilingual framework to support language extensions
  * Modify the format of session files
  * Modify the loading and display of data files
  * Optimize the switching between multiple devices
  * Add a mandatory prompt to save data when switching
  * Update demo device
  * Added the ability to view and clear logs
  for logic analyzer
  * Add real-time display support for stream mode
  * Add scrolling (loop) mode to continuously collect and display in real-time
  * Update repeat mode to maintain previous waveform before switching
  * Update the display and search of waveform edges
  * Add and fix decoders (e.g., can-fd, mipi-rffe, UFCS, etc.)
  * Support ordering of decoders and waveform channels, and remember the order
  * Support exporting multiple column decoding results to the same CSV file
  * Support mapping and saving of decoder names and decoding channel names
  * Add Chinese translation for decoder options
  for oscilloscope
  * Update the data storage method for oscilloscope channels
  * Fix an issue with file saving when using single channel
* Thu Mar 16 2023 Fabian Vogt <fvogt@suse.com>
- Update to 1.2.2:
  common:
  * Add shortcut key recognition of ctrl/shift/alt
  * Fix multiple clicks crash during file saving
  * Fix screenshot crash under macOS
  * Improve accuracy of CSV file
  for logic analyzer:
  * Support new hardware and firmware versions
  * Clean up 0: UART protocol outputs statement
  * Add CAN decoder support for CANFD
  * Fix wait error for some decoders
  * Fix QI decoder bugs
  * Fix SPDIF decoder error for incomplete frames
  * Add message type support for USB PD decoder
  for oscilloscope:
  * Fix measure error of DSL files with different channel number
- Remove various unnecessary BuildRequires
* Fri Nov 25 2022 Dmitry Roshchin <dmitry_r@opensuse.org>
- Update to version 1.2.1
- Drop deparate library packages
- Drop DSView-remove-unnecessary-extern-C.patch
- Drop qt5-includefixes.patch
* Wed Jan 12 2022 Wojciech Kazubski <wk@ire.pw.edu.pl>
- added a patch DSView-remove-unnecessary-extern-C.patch, taken
  from upstream, to fix build on Tumbleweed and Leap 15.4
* Sat Feb 20 2021 Dirk Müller <dmueller@suse.com>
- update to 1.1.2:
  * fix issue of saving/loading file with special characters
  * fix issue #226, double-click open dsl file on Windows
  * improve range settings in decoders
  * add QSPI and MIPI DSI decoders
  * merge enhancement of LPC decoder
  * fix issue #300, time precision for csv export of decoder results
  * fix out-of-order issue of multiple annotation rows in one decoder
  * fix issue #306, VCD file export uses the wrong identifier codes
  * improve the icons with svg format for better high DPI display
  * fix out of screen issue when DPI scale >= 1.5 @ 1080P
  * fix type-c orientation issue for U3Pro16/U3Pro32
  * fix decoder issues (enhance detection of i2s stop and dmx512 break)
  * improve the auto gain control during auto calibration for U2B100/U3P100
  * fix issue of first trigger be ignored
  * add support for DSCope U3P100 device (100M bandwidth/1G samplerate/USB3.0 oscilloscope)
  * add support for DSLogic U3Pro32 device (32 channels/1G samplerate/USB3.0 logic analyzer)
  * add support for DSCope U2B100 device (100M bandwidth/1G samplerate/USB2.0 oscilloscope)
  * add support for DSLogic U3Pro16 device (16 channels/1G samplerate/USB3.0 logic analyzer)
  * add display of device type (USB 2.0 / USB 3.0 / Demo / File)
  * add version check for FPGA firmware
  * improve the default file name when saving/exporting files
  * fix other display and language issue
  * extend channel support for trigger up to 32 channels
  * fix issue of ps/2 decoder (#239)
  * fix issue of cec decoder (#235)
  * fix ID issue when export results of decoder (#237)
  * fix "not" logic don't work in advance trigger
  * fix other display issues
  * improve wave shake issue when trig high freqency signals
  * fix sampling point selection issue of downsampling
  * add 20M bandwidth limitation for DSCope U2B100 / DSCope U3P100 devices
  * improve synchronism between data acquisition and wave dispaly
  * fix wave display and measurement issue when change vdiv and offset after stop
  * fix capture restart issue when change offset in roll mode
  * fix issue of timebase of math channel can't be changed when waiting trigger
  * fix issue of offset can't be changed when waiting trigger
  * fix clear and flicker issue of auto measurements
  * fix cursor and mouse measurements issue after change samplerate when waiting trigger
  * fix trigger issue when toggle between different trigger source
  * fix hardware offset setting issue
  * fix mipmap issue of long time data at some case
  * add cursor and mouse measurements
- add qt5-includefixes.patch
- merge build of libsigrokdecode4DSL and libsigrok4DSL into main package
* Sun Oct  6 2019 Dmitry Roshchin <dmitry_r@opensuse.org>
- Initial package, version 1.01
